@@ -68,7 +68,7 @@ typedef
 	struct {
 		GB_BASE ob;
 		GstElement *elt;
-		void *dest;
+		void **dest;
 		GB_VARIANT_VALUE tag;
 		unsigned state : 3;
 		unsigned error : 1;
@@ -105,6 +105,7 @@ typedef
 	struct {
 		GB_BASE ob;
 		GstMessage *message;
+		const GstStructure *structure;
 		const char *lastKey;
 	}
 	CMEDIAMESSAGE;
