@@ -215,38 +215,27 @@ void CURL_manage_error(void *_object, int error)
 		THIS_FILE = NULL;
 	}
 	
-	switch (error)
+	if (THIS->async)
 	{
-		case CURLE_OK:
-			
-			if (THIS->async) 
-			{
-				#if DEBUG
-				fprintf(stderr, "-- [%p] curl_multi_remove_handle(%p)\n", THIS, THIS_CURL);
-				#endif
-				curl_multi_remove_handle(CCURL_multicurl,THIS_CURL);
-			}
-			GB.Ref(THIS);
-			GB.Post(CURL_raise_finished, (intptr_t)THIS);
-			CURL_stop(THIS);
-			THIS_STATUS = NET_INACTIVE;
-			break;
-			
-		default:
-			
-			if (THIS->async) 
-			{
-				#if DEBUG
-				fprintf(stderr, "-- [%p] curl_multi_remove_handle(%p)\n", THIS, THIS_CURL);
-				#endif
-				curl_multi_remove_handle(CCURL_multicurl,THIS_CURL);
-			}
-			GB.Ref(THIS);
-			GB.Post(CURL_raise_error, (intptr_t)THIS);
-			CURL_stop(THIS);
-			THIS_STATUS = (- (1000 + error));
-			break;
+		#if DEBUG
+		fprintf(stderr, "-- [%p] curl_multi_remove_handle(%p)\n", THIS, THIS_CURL);
+		#endif
+		curl_multi_remove_handle(CCURL_multicurl,THIS_CURL);
 	}
+
+	GB.Ref(THIS);
+
+	if (error == CURLE_OK)
+		GB.Post(CURL_raise_finished, (intptr_t)THIS);
+	else
+		GB.Post(CURL_raise_error, (intptr_t)THIS);
+
+	CURL_stop(THIS);
+
+	if (error == CURLE_OK)
+		THIS_STATUS = NET_INACTIVE;
+	else
+		THIS_STATUS = (- (1000 + error));
 }
 
 void CURL_init_stream(void *_object)
@@ -348,19 +337,6 @@ void CURL_stop(void *_object)
 	if (THIS_STATUS == NET_INACTIVE)
 		return;
 	
-	if (THIS_CURL)
-	{
-		#if DEBUG
-		fprintf(stderr, "-- CURL_stop: [%p] curl_multi_remove_handle(%p)\n", THIS, THIS_CURL);
-		#endif
-		curl_multi_remove_handle(CCURL_multicurl,THIS_CURL);
-		#if DEBUG
-		fprintf(stderr, "-- CURL_stop: [%p] curl_easy_cleanup(%p)\n", THIS, THIS_CURL);
-		#endif
-		curl_easy_cleanup(THIS_CURL);
-		THIS_CURL = NULL;
-	}
-
 	if (THIS_FILE)
 	{
 		fclose(THIS_FILE);
@@ -372,6 +348,22 @@ void CURL_stop(void *_object)
 	remove_from_async_list(THIS);
 }
 
+void CURL_clean(void *_object)
+{
+	if (THIS_CURL)
+	{
+		#if DEBUG
+		fprintf(stderr, "-- CURL_clean: [%p] curl_multi_remove_handle(%p)\n", THIS, THIS_CURL);
+		#endif
+		curl_multi_remove_handle(CCURL_multicurl,THIS_CURL);
+		#if DEBUG
+		fprintf(stderr, "-- CURL_clean: [%p] curl_easy_cleanup(%p)\n", THIS, THIS_CURL);
+		#endif
+		curl_easy_cleanup(THIS_CURL);
+		THIS_CURL = NULL;
+	}
+}
+
 static void init_post(void)
 {
 	if (CCURL_pipe[0]!=-1) return;
@@ -601,6 +593,7 @@ BEGIN_METHOD_VOID(Curl_free)
 	#endif
 	
 	CURL_stop(THIS);
+	CURL_clean(THIS);
 	
 	GB.FreeString(&THIS_URL);
 	GB.FreeString(&THIS->target);
