@@ -90,11 +90,14 @@ static void ftp_reset(void *_object)
 
 static void ftp_initialize_curl_handle(void *_object)
 {
+	fprintf(stderr, "ftp_initialize_curl_handle: %p\n", THIS_CURL);
+
 	if (THIS_CURL)
 	{
 		if (CURL_check_userpwd(&THIS->user))
 		{
 			CURL_stop(_object);
+			CURL_clean(_object);
 			ftp_reset(_object);
 			THIS_CURL = curl_easy_init();
 			#if DEBUG
@@ -110,9 +113,13 @@ static void ftp_initialize_curl_handle(void *_object)
 		#endif
 	}
 
+	fprintf(stderr, "ftp_initialize_curl_handle: --> %p\n", THIS_CURL);
+
 	CURL_init_options(THIS);
 
 	curl_easy_setopt(THIS_CURL, CURLOPT_FTP_USE_EPSV, (long)(THIS_FTP->no_epsv ? 0 : 1));
+	curl_easy_setopt(THIS_CURL, CURLOPT_QUOTE, NULL);
+	curl_easy_setopt(THIS_CURL, CURLOPT_NOBODY, 0);
 
 	ftp_reset(THIS_FTP);
 	THIS_STATUS = NET_CONNECTING;
