@@ -2,7 +2,7 @@
 
   CWindow.cpp
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -622,7 +622,7 @@ static bool do_close(CWINDOW *_object, int ret, bool destroyed = false)
 	bool closed;
 
 	#if DEBUG_WINDOW
-	qDebug("do_close: (%s %p) %d %d", GB.GetClassName(THIS), THIS, THIS->closing, THIS->closed);
+	fprintf(stderr, "do_close: (%s %p) %d %d\n", GB.GetClassName(THIS), THIS, THIS->closing, THIS->closed);
 	#endif
 
 	if (THIS->closing || THIS->closed) // || WIDGET->isHidden())
@@ -1624,30 +1624,6 @@ MyMainWindow::~MyMainWindow()
 	//qDebug("~MyMainWindow %p (end)", this);
 }
 
-#if 0
-bool MyMainWindow::event(QEvent *e)
-{
-	if (e->spontaneous() && !CWIDGET_test_flag(THIS, WF_DELETED))
-	{
-		/*if (e->type() == QEvent::WindowActivate)
-		{
-			qDebug("activate: %s %p", GB.GetClassName(THIS), THIS);
-			//CWINDOW_activate((CWIDGET *)THIS);
-			GB.Ref(THIS);
-			GB.Post((void (*)())activate_later, (intptr_t)THIS);
-
-		}
-		else*/ if (e->type() == QEvent::WindowDeactivate)
-		{
-			qDebug("deactivate: %s %p", GB.GetClassName(THIS), THIS);
-			if (THIS == CWINDOW_Active)
-				CWINDOW_activate(NULL);
-		}
-	}
-
-	return QWidget::event(e);
-}
-#endif
 
 void MyMainWindow::showEvent(QShowEvent *e)
 {
@@ -1937,10 +1913,15 @@ void MyMainWindow::doShowModal(bool popup, const QPoint *pos)
 
 	_enterLoop = false; // Do not call exitLoop() if we do not entered the loop yet!
 
+	parent = CWINDOW_Current;
+	if (!parent)
+		parent = CWINDOW_Active;
+
 	if (popup)
 	{
-		setWindowFlags(Qt::Popup | info.flags);
-		
+		if (parent)
+			setParent(CWidget::getTopLevel((CWIDGET *)parent)->widget.widget, Qt::Popup | info.flags);
+
 		move(0, 0);
 		move(*pos);
 		setFocus();
@@ -1952,10 +1933,6 @@ void MyMainWindow::doShowModal(bool popup, const QPoint *pos)
 		if (_resizable && _border)
 			setSizeGrip(true);
 
-		parent = CWINDOW_Current;
-		if (!parent)
-			parent = CWINDOW_Active;
-
 		if (parent)
 			setParent(CWidget::getTopLevel((CWIDGET *)parent)->widget.widget, Qt::Window | info.flags);
 		
@@ -2372,7 +2349,7 @@ void MyMainWindow::resizeEvent(QResizeEvent *e)
   	//qDebug("resizeEvent %ld %ld isHidden:%s shown:%s ", THIS->w, THIS->h, isHidden() ? "1" : "0", shown ? "1" : "0");
 	//qDebug("THIS->h = %ld  THIS->container->height() = %ld  height() = %ld", THIS->h, THIS->container->height(), height());
 
-	if (THIS->opened && (e->spontaneous() || parentWidget()))
+	if (THIS->opened) // && (e->spontaneous() || parentWidget()))
 		raise_resize_event(THIS);
 }
 
@@ -2904,9 +2881,10 @@ void MyMainWindow::setBetterMask(QPixmap &bg)
 void MyMainWindow::activate(void)
 {
 #ifdef QT5
-	if (!MAIN_platform_is_wayland)
+	PLATFORM.Window.Activate(this);
+#else
+	activateWindow();
 #endif
-		activateWindow();
 }
 
 bool MyMainWindow::focusNextPrevChild(bool next)
@@ -3008,7 +2986,7 @@ void CWINDOW_activate(CWIDGET *ob)
 	if (CWINDOW_Active)
 	{
 		GB.Raise(CWINDOW_Active, EVENT_Deactivate, 0);
-		CWINDOW_Active = 0;
+		CWINDOW_Active = NULL;
 	}
 
 	if (active)
